import optparse
import typing

from mydots import extractors


class OptionParser(optparse.OptionParser):
    def parse_args_and_values(
        self, args=None, values=None
    ) -> tuple[dict[str, typing.Any], list[str]]:
        options, args = super().parse_args(args=args, values=values)
        return vars(options), args


parser = OptionParser()
parser.add_option(
    "-s",
    "--separator",
    action="store",
    dest="separator",
    default="\n",
)
parser.add_option(
    "-e",
    "--escape-strings",
    action="store_false",
    dest="raw_strings",
    default=True,
)


def main() -> None:
    options, args = parser.parse_args_and_values()
    if len(args) == 0:
        print("Please provide patterns.")
        exit(1)
    extractor = extractors.Extractor(options, args)
    extractor.extract()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mydots']

package_data = \
{'': ['*']}

entry_points = \
{'console_scripts': ['mydots = mydots.__main__:cli.main']}

setup_kwargs = {
    'name': 'mydots',
    'version': '0.3.0',
    'description': 'A simple JSON parser.',
    'long_description': 'mydots\n======\n\nA simple JSON parser.\n\n',
    'author': 'Łukasz Wieczorek',
    'author_email': 'wieczorek1990@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
